/*
 * Copyright 2008 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.derquinsej.collect;

import java.util.List;

import com.google.common.base.Preconditions;
import com.google.common.collect.ForwardingObject;

/**
 * A hierarchy that forward its method calls to a delegated hierarchy.
 * @author Andres Rodriguez
 * @param <K> Type of the keys.
 * @param <V> Type of the elements.
 */
public class ForwardingHierarchy<K, V> extends ForwardingObject implements Hierarchy<K, V> {
	private final Hierarchy<K, V> delegate;

	public ForwardingHierarchy(final Hierarchy<K, V> delegate) {
		Preconditions.checkNotNull(delegate);
		this.delegate = delegate;
	}

	@Override
	protected Object delegate() {
		return delegate;
	}

	public boolean contains(V element) {
		return delegate.contains(element);
	}

	public boolean containsKey(K key) {
		return delegate.containsKey(key);
	}

	public V get(K key) {
		return delegate.get(key);
	}

	public List<V> getChildren(V element) {
		return delegate.getChildren(element);
	}

	public List<V> getChildrenByKey(K key) {
		return delegate.getChildrenByKey(key);
	}

	public List<V> getFirstLevel() {
		return delegate.getFirstLevel();
	}

	public V getParent(V element) {
		return delegate.getParent(element);
	}

	public V getParentByKey(K key) {
		return delegate.getParentByKey(key);
	}
}
